#!/usr/bin/env python3
#
# Copyright 2017-2022 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS-IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
SUBSETS = [
  "arabic",
  "armenian",
  "avestan",
  "balinese",
  "bamum",
  "batak",
  "bengali",
  "brahmi",
  "buginese",
  "buhid",
  "myanmar",
  "canadian-aboriginal",
  "carian",
  "cham",
  "chakma",
  "cherokee",
  "chinese-simplified",
  "chinese-traditional",
  "coptic",
  "cuneiform",
  "cypriot",
  "cyrillic",
  "cyrillic-ext",
  "deseret",
  "egyptian-hieroglyphs",
  "ethiopic",
  "georgian",
  "gothic",
  "greek",
  "greek-ext",
  "gujarati",
  "gurmukhi",
  "hanunoo",
  "hebrew",
  "imperial-aramaic",
  "inscriptional-pahlavi",
  "inscriptional-parthian",
  "devanagari",
  "japanese",
  "javanese",
  "kaithi",
  "kannada",
  "kayah-li",
  "kharoshthi",
  "khmer",
  "korean",
  "lao",
  "latin",
  "latin-ext",
  "lepcha",
  "limbu",
  "linear-b",
  "lisu",
  "lycian",
  "lydian",
  "malayalam",
  "mandaic",
  "meetei-mayek",
  "mongolian",
  "new-tai-lue",
  "ol-chiki",
  "old-italic",
  "old-persian",
  "old-south-arabian",
  "old-turkic",
  "ogham",
  "oriya",
  "osmanya",
  "phags-pa",
  "runic",
  "samaritan",
  "phoenician",
  "rejang",
  "saurashtra",
  "shavian",
  "sinhala",
  "sundanese",
  "syloti-nagri",
  "syriac-eastern",
  "syriac-estrangela",
  "syriac-western",
  "tagalog",
  "tagbanwa",
  "tai-le",
  "tai-tham",
  "tai-viet",
  "tamil",
  "telugu",
  "thaana",
  "thai",
  "tibetan",
  "tifinagh",
  "vai",
  "ugaritic",
  "vietnamese",
  "yi"
]
